==> libkarma-0.0.2.tar.gz: libkarma-0.0.2/src/errors.c <==
/*
 * libkarma/errors.c
 *
 * Copyright (c) Enrique Vidal 2004
 *           (c) Frank Zschockelt <libkarma@freakysoft.de> 2004
 *
 * You may distribute and modify this program under the terms of 
 * the GNU GPL, version 2 or later.
 *
 */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>

#include "errors.h"

const char * lkerrorList[MAXLKERRORS+1] = {
  /* E_NOERR      0 */ "",
  /* E_HOST       1 */ "** Libkarma error: gethostbyname() failed",
  /* E_SOCKET     2 */ "** Libkarma error: socket() failed",
  /* E_SENDTO     3 */ "** Libkarma error: sendto() failed",
  /* E_CONNECT    4 */ "** Libkarma error: connect() failed",
  /* E_RECVFROM   5 */ "** Libkarma error: recvfrom() failed",
  /* E_SELECT     6 */ "** Libkarma error: select() failed",
  /* E_OPEN       7 */ "** Libkarma error: open() failed",
  /* E_ICONVO     8 */  "* Libkarma warning: iconv_open() failed",
  /* E_ICONV      9 */  "* Libkarma warning: iconv() failed",
  /* E_ICONVC    10 */ "** Libkarma error: iconv_close() failed",
  /* E_BADHEADER 11 */ "** Libkarma error: broken Rio header",
  /* E_BADIDENT  12 */ "** Libkarma error: wrong protocol identifier",
  /* E_FAILEDREQ 13 */  "* Libkarma warning: failed request",
  /* E_BADPROP   14 */ "** Libkarma error: property parsing failed",
  /* E_BADID     15 */ "** Libkarma error: given id not found",
  /* E_NOSSDP    16 */  "* Libkarma warning: no ssdp answer",
  /* E_SSDPPARSE 17 */  "* Libkarma warning: ssdp parsing failed"
};

#define libkarmaErrorString lkerrorList[libkarmaError]
#define previousErrorString lkerrorList[previousError]

/* libkarmaErrorString is assumedly valid only if libkarmaErrorFlag == 1 */
static int  libkarmaError = 0;
static int  previousError = 0;
static int  autoPrintErrors = 1;

/* ---------------------------- Error Setting --------------------------- */
int lkerrSet(const int err) {
  lkerror();
  if ((err < 0) || (err >= MAXLKERRORS)) return -1;
  libkarmaError = err;
  if (autoPrintErrors) 
    fprintf(stderr, "%s\n", libkarmaErrorString);
  return 0;
}

/* -------------------------- Error checking -------------------------- */
void lkerrAutoPrint(const int autoPrint) {
  autoPrintErrors = autoPrint;
}

int lkerror() { /* checks for current error number and backs-up and resets it */
  previousError = libkarmaError;
  libkarmaError = 0;
  return previousError;
}

int lkerrNoReset() {
  return libkarmaError;
}

int lkerrorp(const char *s1, const char *s2) {
  if (lkerror()) 
    fprintf(stderr, "%s%s%s\n", s1, previousErrorString, s2); 
  return previousError;
}

char * lkerrorstr(int lkerrnum) {
  if ((lkerrnum < 0) || (lkerrnum >= MAXLKERRORS)) return NULL;
  return (char * )lkerrorList[lkerrnum];
}

==> libkarma-0.0.3.tar.gz: libkarma-0.0.3/src/errors.c <==
/*
 * libkarma/errors.c
 *
 * Copyright (c) Enrique Vidal 2004
 *           (c) Frank Zschockelt <libkarma@freakysoft.de> 2004
 *
 * You may distribute and modify this program under the terms of 
 * the GNU GPL, version 2 or later.
 *
 */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>

#include "errors.h"

const char * lkerrorList[MAXLKERRORS+1] = {
  /* E_NOERR      0 */ "",
  /* E_HOST       1 */ "** Libkarma error: gethostbyname() failed",
  /* E_SOCKET     2 */ "** Libkarma error: socket() failed",
  /* E_SENDTO     3 */ "** Libkarma error: sendto() failed",
  /* E_CONNECT    4 */ "** Libkarma error: connect() failed",
  /* E_RECVFROM   5 */ "** Libkarma error: recvfrom() failed",
  /* E_SELECT     6 */ "** Libkarma error: select() failed",
  /* E_OPEN       7 */ "** Libkarma error: open() failed",
  /* E_ICONVO     8 */  "* Libkarma warning: iconv_open() failed",
  /* E_ICONV      9 */  "* Libkarma warning: iconv() failed",
  /* E_ICONVC    10 */ "** Libkarma error: iconv_close() failed",
  /* E_BADHEADER 11 */ "** Libkarma error: broken Rio header",
  /* E_BADIDENT  12 */ "** Libkarma error: wrong protocol identifier",
  /* E_FAILEDREQ 13 */  "* Libkarma warning: failed request",
  /* E_BADPROP   14 */ "** Libkarma error: property parsing failed",
  /* E_BADID     15 */ "** Libkarma error: given id not found",
  /* E_NOSSDP    16 */  "* Libkarma warning: no ssdp answer",
  /* E_SSDPPARSE 17 */  "* Libkarma warning: ssdp parsing failed",
  /* E_MKDIR     18 */ "** Libkarma error: mkdir() failed",
  /* E_UTIME     19 */  "* Libkarma error: utime() failed"
};

#define libkarmaErrorString lkerrorList[libkarmaError]
#define previousErrorString lkerrorList[previousError]

/* libkarmaErrorString is assumedly valid only if libkarmaErrorFlag == 1 */
static int  libkarmaError = 0;
static int  previousError = 0;
static int  autoPrintErrors = 1;

/* ---------------------------- Error Setting --------------------------- */
int lkerrSet(const int err) {
  lkerror();
  if ((err < 0) || (err >= MAXLKERRORS)) return -1;
  libkarmaError = err;
  if (autoPrintErrors) 
    fprintf(stderr, "%s\n", libkarmaErrorString);
  return 0;
}

/* -------------------------- Error checking -------------------------- */
void lkerrAutoPrint(const int autoPrint) {
  autoPrintErrors = autoPrint;
}

int lkerror() { /* checks for current error number and backs-up and resets it */
  previousError = libkarmaError;
  libkarmaError = 0;
  return previousError;
}

int lkerrNoReset() {
  return libkarmaError;
}

int lkerrorp(const char *s1, const char *s2) {
  if (lkerror()) 
    fprintf(stderr, "%s%s%s\n", s1, previousErrorString, s2); 
  return previousError;
}

char * lkerrorstr(int lkerrnum) {
  if ((lkerrnum < 0) || (lkerrnum >= MAXLKERRORS)) return NULL;
  return (char * )lkerrorList[lkerrnum];
}
